==> angular_components-0.8.0.tar.gz: lib/material_input/material_input_default_value_accessor.dart <==
// Copyright (c) 2016, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'package:angular/angular.dart';
import 'package:angular_components/utils/disposer/disposer.dart';
import 'package:angular_forms/angular_forms.dart';
import 'package:meta/meta.dart';

import 'base_material_input.dart';

/// [ControlValueAccessor] for [MaterialInputComponent] that updates on
/// keypress.
// TODO(google): Migrate away from this being the default accessor.
@Directive(selector: 'material-input:not([blurUpdate]):not([changeUpdate]))')
class MaterialInputDefaultValueAccessor extends BaseMaterialInputValueAccessor
    implements ControlValueAccessor, OnDestroy {
  MaterialInputDefaultValueAccessor(
      BaseMaterialInput input, @Self() @Optional() NgControl control)
      : super(input, control);

  @override
  void registerOnChange(callback) {
    disposer.addStreamSubscription(input.onKeypress.listen((value) {
      callback(value);
    }));
  }
}

/// [ControlValueAccessor] to be used with a [MaterialInputComponent] that
/// updates on blur.
@Directive(selector: 'material-input[blurUpdate]')
class MaterialInputBlurValueAccessor extends BaseMaterialInputValueAccessor
    implements ControlValueAccessor, OnDestroy {
  MaterialInputBlurValueAccessor(
      BaseMaterialInput input, @Self() @Optional() NgControl control)
      : super(input, control);

  @override
  void registerOnChange(callback) {
    disposer.addStreamSubscription(input.onBlur.listen((_) {
      if (input != null) callback(input.inputText);
    }));
  }
}

/// [ControlValueAccessor] to be used with a [MaterialInputComponent] that
/// updates on change.
@Directive(selector: 'material-input[changeUpdate]')
class MaterialInputChangeValueAccessor extends BaseMaterialInputValueAccessor
    implements ControlValueAccessor, OnDestroy {
  MaterialInputChangeValueAccessor(
      BaseMaterialInput input, @Self() @Optional() NgControl control)
      : super(input, control);

  @override
  void registerOnChange(callback) {
    disposer.addStreamSubscription(input.onChange.listen((_) {
      if (input != null) callback(input.inputText);
    }));
  }
}

/// Common logic for a [ControlValueAccessor] for a
/// [BaseMaterialInputComponent].
abstract class BaseMaterialInputValueAccessor
    implements ControlValueAccessor, OnDestroy {
  @protected
  final disposer = new Disposer.oneShot();
  @protected
  final BaseMaterialInput input;
  final NgControl _cd;

  BaseMaterialInputValueAccessor(this.input, @Self() @Optional() this._cd) {
    // To get around a circular dependency injection assign the valueAccessor
    // ourselves.
    _cd?.valueAccessor = this;
    disposer.addFunction(() {
      // Kill the control's handle on this accessor directive so that it can be
      // GC'ed.
      _cd?.valueAccessor = null;
    });
  }

  @override
  void writeValue(newValue) {
    input.inputText = newValue;
  }

  @override
  void registerOnTouched(callback) {
    var sub;
    sub = input.onBlur.listen((_) {
      sub.cancel(); // We only need the first event. Cancel the subscription.
      callback();
    });
    disposer.addStreamSubscription(sub);
  }

  @override
  void ngOnDestroy() {
    disposer.dispose();
  }
}

==> angular_components-0.11.0.tar.gz: lib/material_input/material_input_default_value_accessor.dart <==
// Copyright (c) 2016, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'package:angular/angular.dart';
import 'package:angular_forms/angular_forms.dart';
import 'package:meta/meta.dart';
import 'package:angular_components/utils/disposer/disposer.dart';

import 'base_material_input.dart';

/// [ControlValueAccessor] for [MaterialInputComponent] that updates on
/// keypress.
///
/// Note: This is less accessible since any errors that are produced by the
/// input are shown immediately which is distracting when using a screen reader.
/// instead please consider using [blurUpdate] which only shows errors after
/// a blur event.
// TODO(google): Migrate away from this being the default accessor.
@Directive(
  selector: 'material-input:not([blurUpdate]):not([changeUpdate])',
  // TODO(google): Change to `Visibility.local` to reduce code size.
  visibility: Visibility.all,
)
class MaterialInputDefaultValueAccessor extends BaseMaterialInputValueAccessor
    implements ControlValueAccessor, OnDestroy {
  MaterialInputDefaultValueAccessor(
      BaseMaterialInput input, @Self() @Optional() NgControl control)
      : super(input, control);

  @override
  void registerOnChange(callback) {
    disposer.addStreamSubscription(input.onKeypress.listen((value) {
      callback(value);
    }));
  }
}

/// [ControlValueAccessor] to be used with a [MaterialInputComponent] that
/// updates on blur.
@Directive(
  selector: 'material-input[blurUpdate]',
  // TODO(google): Change to `Visibility.local` to reduce code size.
  visibility: Visibility.all,
)
class MaterialInputBlurValueAccessor extends BaseMaterialInputValueAccessor
    implements ControlValueAccessor, OnDestroy {
  MaterialInputBlurValueAccessor(
      BaseMaterialInput input, @Self() @Optional() NgControl control)
      : super(input, control);

  @override
  void registerOnChange(callback) {
    disposer.addStreamSubscription(input.onBlur.listen((_) {
      if (input != null) callback(input.inputText);
    }));
  }
}

/// [ControlValueAccessor] to be used with a [MaterialInputComponent] that
/// updates on change.
@Directive(
  selector: 'material-input[changeUpdate]',
  // TODO(google): Change to `Visibility.local` to reduce code size.
  visibility: Visibility.all,
)
class MaterialInputChangeValueAccessor extends BaseMaterialInputValueAccessor
    implements ControlValueAccessor, OnDestroy {
  MaterialInputChangeValueAccessor(
      BaseMaterialInput input, @Self() @Optional() NgControl control)
      : super(input, control);

  @override
  void registerOnChange(callback) {
    disposer.addStreamSubscription(input.onChange.listen((_) {
      if (input != null) callback(input.inputText);
    }));
  }
}

/// Common logic for a [ControlValueAccessor] for a
/// [BaseMaterialInputComponent].
abstract class BaseMaterialInputValueAccessor
    implements ControlValueAccessor, OnDestroy {
  @protected
  final disposer = Disposer.oneShot();
  @protected
  final BaseMaterialInput input;
  final NgControl _cd;

  BaseMaterialInputValueAccessor(this.input, @Self() @Optional() this._cd) {
    // To get around a circular dependency injection assign the valueAccessor
    // ourselves.
    _cd?.valueAccessor = this;
    disposer.addFunction(() {
      // Kill the control's handle on this accessor directive so that it can be
      // GC'ed.
      _cd?.valueAccessor = null;
    });
  }

  @override
  void writeValue(newValue) {
    input.inputText = newValue;
  }

  @override
  void registerOnTouched(callback) {
    var sub;
    sub = input.onBlur.listen((_) {
      sub.cancel(); // We only need the first event. Cancel the subscription.
      callback();
    });
    disposer.addStreamSubscription(sub);
  }

  @override
  void ngOnDestroy() {
    disposer.dispose();
  }

  @override
  void onDisabledChanged(bool isDisabled) {
    input.disabled = isDisabled;
  }
}
